package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppPartnerbinding;

/**
 * 合伙人绑定Service接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IAppPartnerbindingService 
{
    /**
     * 查询合伙人绑定
     * 
     * @param id 合伙人绑定主键
     * @return 合伙人绑定
     */
    public AppPartnerbinding selectAppPartnerbindingById(Long id);

    /**
     * 查询合伙人绑定列表
     * 
     * @param appPartnerbinding 合伙人绑定
     * @return 合伙人绑定集合
     */
    public List<AppPartnerbinding> selectAppPartnerbindingList(AppPartnerbinding appPartnerbinding);

    /**
     * 新增合伙人绑定
     * 
     * @param appPartnerbinding 合伙人绑定
     * @return 结果
     */
    public int insertAppPartnerbinding(AppPartnerbinding appPartnerbinding);

    /**
     * 修改合伙人绑定
     * 
     * @param appPartnerbinding 合伙人绑定
     * @return 结果
     */
    public int updateAppPartnerbinding(AppPartnerbinding appPartnerbinding);

    /**
     * 批量删除合伙人绑定
     * 
     * @param ids 需要删除的合伙人绑定主键集合
     * @return 结果
     */
    public int deleteAppPartnerbindingByIds(Long[] ids);

    /**
     * 删除合伙人绑定信息
     * 
     * @param id 合伙人绑定主键
     * @return 结果
     */
    public int deleteAppPartnerbindingById(Long id);
}
