package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppPartnerbinding;
import com.ruoyi.model.service.IAppPartnerbindingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人绑定Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/AppPartnerbinding")
public class AppPartnerbindingController extends BaseController
{
    @Autowired
    private IAppPartnerbindingService appPartnerbindingService;

    /**
     * 查询合伙人绑定列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppPartnerbinding appPartnerbinding)
    {
        startPage();
        List<AppPartnerbinding> list = appPartnerbindingService.selectAppPartnerbindingList(appPartnerbinding);
        return getDataTable(list);
    }

    /**
     * 导出合伙人绑定列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:export')")
    @Log(title = "合伙人绑定", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppPartnerbinding appPartnerbinding) throws IOException {
        List<AppPartnerbinding> list = appPartnerbindingService.selectAppPartnerbindingList(appPartnerbinding);
        ExcelUtil<AppPartnerbinding> util = new ExcelUtil<AppPartnerbinding>(AppPartnerbinding.class);
        util.exportExcel(response, list, "合伙人绑定数据");
    }

    /**
     * 获取合伙人绑定详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appPartnerbindingService.selectAppPartnerbindingById(id));
    }

    /**
     * 新增合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:add')")
    @Log(title = "合伙人绑定", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppPartnerbinding appPartnerbinding)
    {
        return toAjax(appPartnerbindingService.insertAppPartnerbinding(appPartnerbinding));
    }

    /**
     * 修改合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:edit')")
    @Log(title = "合伙人绑定", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppPartnerbinding appPartnerbinding)
    {
        return toAjax(appPartnerbindingService.updateAppPartnerbinding(appPartnerbinding));
    }

    /**
     * 删除合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerbinding:remove')")
    @Log(title = "合伙人绑定", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appPartnerbindingService.deleteAppPartnerbindingByIds(ids));
    }
}
